@@ -171,8 +171,8 @@ static char* start_end_msg =	N_("START and END are disk locations, such as "
 //static char* state_msg =	N_("STATE is one of: on, off\n");
 // static char* device_msg =	N_("DEVICE is usually /dev/hda or /dev/sda\n");
 // static char* name_msg =		N_("NAME is any word you want\n");
-static char* resize_msg_start = N_("The partition must have one of the "
-				   "following FS-TYPEs: ");
+//static char* resize_msg_start = N_("The partition must have one of the "
+//				   "following FS-TYPEs: ");
 
 static char* label_type_msg;
 static char* flag_msg;
@@ -662,79 +662,32 @@ do_mklabel (PedDisk** disk)
 	return perform_mklabel(dev,disk,type);
 }
 #endif
+
+#if 0
 static int
 do_mkfs (PedDisk** disk)
 {
 
 	return perform_mkfs(*disk,NULL,NULL,UI_WARN_COMMIT);
 }
+#endif
 
 static int
-do_mkpart (PedDisk **disk)
+do_mkpart (PedDisk ** disk)
 {
-	PartPos			 pos;
-	PedPartitionType	 part_type = 0;
-	const PedFileSystemType	*fs_type = ped_file_system_type_get ("ext2");
-	char*			 peek_word;
-	UIOpts			 opts = UI_CUSTOM_VALUES;
+  PartPos pos;
+  PedPartitionType part_type = 0;
+  UIOpts opts = UI_CUSTOM_VALUES;
 
+  if (!get_part_type (_("Partition type"), *disk, &part_type))
+    return 0;
 
+  pos.start.sector = 0LL;
+  pos.end.sector = 0LL;
+  pos.start.range = NULL;
+  pos.end.range = NULL;
 
-
-	if (!get_part_type (_("Partition type"), *disk,
-					       &part_type))
-		return 0;
-
-	peek_word = fdisk_command_line_peek_word ();
-	if (part_type == PED_PARTITION_EXTENDED
-	    || (peek_word && isdigit (peek_word[0]))) {
-		fs_type = NULL;
-	}
-	/* gfdisk should ask for filesystem, lfdisk should not */
-	else if (!compat_mode) {
-		if (!get_fs_type (_("File system type"),
-					       &fs_type, 0))
-			return 0;
-	}
-	if (peek_word)
-		PED_FREE (peek_word);
-
-
-	pos.start.sector = 0LL;
-	pos.end.sector = 0LL;
-	pos.start.range = NULL;
-	pos.end.range = NULL;
-
-	/*
-	 * Christian <mail.kristian@yahoo.it> bug-fixed:
-	 *
-	 * (gdb) c
-	 * Continuing.
-	 * Partition type
-	 *   e   extended
-	 *   p   primary partition (1-4)
-	 * e
-	 * 
-	 * Program received signal SIGSEGV, Segmentation fault.
-	 * 0x0804bb3f in do_mkpart (disk=0xbf8c4150) at fdisk.c:673
-	 * 673             if (!fdisk_compatibility_mode && fs_type->ops->create &&
-	 */
-
-	/* if (!fdisk_compatibility_mode && fs_typ->ops->create && */
-
-	if (!compat_mode && fs_type && fs_type->ops->create &&
-	    part_type != PED_PARTITION_EXTENDED &&
-	    command_line_prompt_boolean_question(
-		_("Do you want to create the filesystem on the partition?")))
-	{
-	  return perform_mkpartfs (*disk, &pos, part_type, fs_type,
-				   NULL, opts | UI_WARN_COMMIT);
-	}
-	else
-	{
-	  return perform_mkpart (*disk, &pos, part_type, fs_type,
-				 NULL, opts);
-	}
+  return perform_mkpart (*disk, &pos, part_type, NULL, opts);
 }
 
 #if 0
@@ -753,25 +706,6 @@ do_mkpartfs (PedDisk** disk)
 }
 #endif
 
-static int
-do_move (PedDisk** disk)
-{
-	PartPos pos;
-	/* TODO: Make default position more friendly */
-	pos.start.sector = 0LL;
-	pos.end.sector = 0LL;
-	pos.start.range = NULL;
-	pos.end.range = NULL;
-	if(!perform_move (*disk, NULL, &pos, UI_CUSTOM_VALUES|UI_WARN_COMMIT)) {
-		ped_exception_throw(PED_EXCEPTION_ERROR,
-		                    PED_EXCEPTION_CANCEL,
-		         _("Partition move failed"));
-		if (uiquery.need_commit)
-				_disk_reread(disk);
-		return 0;
-	}
-	return 1;
-}
 // unused
 #if 0
 static int
@@ -1539,166 +1473,65 @@ error:
 }
 
 static int
-do_resize (PedDisk** disk)
+do_resize (PedDisk ** disk)
 {
-	Option query_opts[] = {
-		{ 's', _("don't move the beginning of the partition") },
-		{ 'b', _("place it at the beginning of the free space before it") },
-		{ 'e', _("place it at the end") },
-		{ 'c', _("select custom start and end") },
-		{ '\0', NULL }
+  Option query_opts[] = {
+    {'s', _("don't move the beginning of the partition")},
+    {'b', _("place it at the beginning of the free space before it")},
+    {'e', _("place it at the end")},
+    {'c', _("select custom start and end")},
+    {'\0', NULL}
+  };
 
-	};
-	PartPos pos;
-	PedPartition *part = NULL, *temp;
-	PedSector first,last;
-	PedConstraint *constraint = NULL;
-	PedPartitionType desired;
-	UIOpts ui_opts = UI_WARN_COMMIT | UI_SNAP_TO_START;
+  PartPos pos;
+  PedPartition *part = NULL, *temp;
+  PedSector first, last;
+  PedPartitionType desired;
+  UIOpts ui_opts = UI_WARN_COMMIT | UI_SNAP_TO_START;
 
-	if (!get_partition (_("Partition"), *disk, &part))
-                	return 0;
+  if (!get_partition (_("Partition"), *disk, &part))
+    return 0;
 
-	/* TODO: Almost shared between fdisk and cfdisk, move to common */
-	if (part->fs_type) {
-		if (!part->fs_type->ops->resize) {
-			ped_exception_throw(PED_EXCEPTION_ERROR,
-			                    PED_EXCEPTION_CANCEL,
-			                    _("You can't resize this filesystem type."));
-			return 0;
-		}
-		else {
-			PedFileSystem *fs = ped_file_system_open(&part->geom);
-			constraint = ped_file_system_get_resize_constraint(fs);
-			if (!constraint || constraint->min_size == constraint->max_size)
-			{
-				ped_exception_throw(PED_EXCEPTION_ERROR,
-				                    PED_EXCEPTION_CANCEL,
-				       _("We can't resize this filesystem type"));
-				if (constraint) ped_constraint_destroy(constraint);
-				if (fs) ped_file_system_close (fs);
-				return 0;
-			}
-			if (fs) ped_file_system_close (fs);
-		}
-	}
-	else if (part->type != PED_PARTITION_EXTENDED) {
-		ped_exception_throw(PED_EXCEPTION_ERROR, PED_EXCEPTION_CANCEL,
-		                    _("No filesystem detected on the partition."));
-		return 0;
-	}
-	pos.start.sector = part->geom.start;
-	pos.end.sector = part->geom.end;
+  /* get constraint from device */
+  
+  pos.start.sector = part->geom.start;
+  pos.end.sector = part->geom.end;
 
-	desired = PED_PARTITION_FREESPACE |
-	                           (part->type & PED_PARTITION_LOGICAL);
+  desired = PED_PARTITION_FREESPACE | (part->type & PED_PARTITION_LOGICAL);
 
-	temp = part_list_prev(part,PED_PARTITION_METADATA);
+  temp = part_list_prev (part, PED_PARTITION_METADATA);
 
-	if (temp && (temp->type & desired))
-		first = temp->geom.start;
-	else
-		first = part->geom.start;
+  if (temp && (temp->type & desired))
+    first = temp->geom.start;
+  else
+    first = part->geom.start;
 
-	temp = part_list_next(part,PED_PARTITION_METADATA);
+  temp = part_list_next (part, PED_PARTITION_METADATA);
 
-	if (temp && (temp->type & desired))
-		last = temp->geom.end;
-	else
-		last = part->geom.end;
+  if (temp && (temp->type & desired))
+    last = temp->geom.end;
+  else
+    last = part->geom.end;
 
-	if(!query_part_position(_("Place for the resized partition"),
-	                        query_opts,&pos,first,last,(*disk)->dev,
-	                        constraint,&ui_opts)) {
-		if (constraint) ped_constraint_destroy (constraint);
-		return 0;
-	}
-	if (!perform_resize (*disk, part, &pos, ui_opts)) {
-		ped_exception_throw(PED_EXCEPTION_ERROR,
-		                    PED_EXCEPTION_CANCEL,
-		         _("Resize of the partition failed"));
-		if (!(ui_opts & UI_NO_FS_RESIZE) && uiquery.need_commit)
-				_disk_reread(disk);
-		return 0;
-	}
-	return 1;
-#if 0
-	PedPartition		*part = NULL;
-	PedFileSystem		*fs;
-	PedConstraint		*constraint;
-	PedSector		start, end;
-	PedGeometry             *range_start = NULL, *range_end = NULL;
-	PedGeometry		new_geom;
+  if (!query_part_position (_("Place for the resized partition"),
+			    query_opts, &pos, first, last, (*disk)->dev, NULL, &ui_opts))
+    {
+      return 0;
+    }
 
-	if (!*disk)
-		goto error;
+  if (!perform_resize (*disk, part, &pos, ui_opts))
+    {
+      ped_exception_throw (PED_EXCEPTION_ERROR,
+                           PED_EXCEPTION_CANCEL,
+                           _("Resize of the partition failed"));
+      
+      if (!(ui_opts & UI_NO_FS_RESIZE) && uiquery.need_commit)
+        _disk_reread (disk);
 
-	if (!command_line_prompt_boolean_question
-	(_("WARNING: resize writes all data to disk automatically, continue")))
-	        return 1;
+      return 0;
+    }
 
-	if (!fdisk_command_line_get_partition (_("Partition number?"), *disk, &part))
-		goto error;
-	if (part->type != PED_PARTITION_EXTENDED) {
-		if (!_partition_warn_busy (part))
-			goto error;
-	}
-
-	start = part->geom.start;
-	end = part->geom.end;
-	if (!fdisk_command_line_get_sector (_("Start?"), (*disk)->dev, &start, &range_start))
-		goto error;
-	if (!fdisk_command_line_get_sector (_("End?"), (*disk)->dev, &end, &range_end))
-		goto error;
-
-	if (!ped_geometry_init (&new_geom, (*disk)->dev, start, end - start + 1))
-		goto error;
-	snap_to_boundaries (&new_geom, &part->geom, *disk,
-			    range_start, range_end);
-
-	if (part->type == PED_PARTITION_EXTENDED) {
-		constraint = constraint_from_start_end ((*disk)->dev,
-				range_start, range_end);
-		if (!ped_disk_set_partition_geom (*disk, part, constraint,
-						  new_geom.start, new_geom.end))
-			goto error_destroy_constraint;
-		ped_partition_set_system (part, NULL);
-	} else {
-		fs = ped_file_system_open (&part->geom);
-		if (!fs)
-			goto error;
-		constraint = constraint_intersect_and_destroy (
-				ped_file_system_get_resize_constraint (fs),
-				constraint_from_start_end (
-					(*disk)->dev, range_start, range_end));
-		if (!ped_disk_set_partition_geom (*disk, part, constraint,
-						  new_geom.start, new_geom.end))
-			goto error_close_fs;
-		if (!ped_file_system_resize (fs, &part->geom, timer))
-			goto error_close_fs;
-		/* may have changed... eg fat16 -> fat32 */
-		ped_partition_set_system (part, fs->type);
-		ped_file_system_close (fs);
-	}
-
-	ped_constraint_destroy (constraint);
-	if (range_start != NULL)
-		ped_geometry_destroy (range_start);
-	if (range_end != NULL)
-		ped_geometry_destroy (range_end);
-	return 1;
-
-error_close_fs:
-	ped_file_system_close (fs);
-error_destroy_constraint:
-	ped_constraint_destroy (constraint);
-error:
-	if (range_start != NULL)
-		ped_geometry_destroy (range_start);
-	if (range_end != NULL)
-		ped_geometry_destroy (range_end);
-	return 0;
-#endif
+  return 1;
 }
 
 static int
@@ -1707,6 +1540,31 @@ do_rm (PedDisk** disk)
 	return perform_rm (*disk, NULL);
 }
 
+static int
+do_move (PedDisk** disk)
+{
+  PartPos pos;
+  
+  XASSERT(disk && *disk, return 0);
+
+  /* TODO: Make default position more friendly */
+  pos.start.sector = 0LL;
+  pos.end.sector = 0LL;
+  pos.start.range = NULL;
+  pos.end.range = NULL;
+
+  if(!perform_move (*disk, NULL, &pos, UI_WARN_COMMIT)) 
+    {
+      ped_exception_throw(PED_EXCEPTION_ERROR,
+                          PED_EXCEPTION_CANCEL,
+                          _("Partition move failed"));
+      if (uiquery.need_commit)
+        _disk_reread(disk);
+      return 0;
+    }
+  return 1;
+}
+
 #if 0
 static int
 do_select (PedDisk** disk)
@@ -1817,22 +1675,6 @@ do_commit (PedDisk **disk)
 
 
 
-static int
-do_copy(PedDisk** disk)
-{
-	if (!perform_cp (*disk, NULL, UI_WARN_COMMIT)) {
-		ped_exception_throw(PED_EXCEPTION_ERROR,
-		                    PED_EXCEPTION_CANCEL,
-		         _("Partition copy failed"));
-		if (uiquery.need_commit)
-				_disk_reread(disk);
-		return 0;
-	}
-	return 1;
-}
-
-
-
 static int
 do_ex_menu (PedDisk** disk) {
 	int status,old_menu;
@@ -2071,26 +1913,6 @@ _init_messages ()
 	label_type_msg = str_list_convert (list);
 	str_list_destroy (list);
 
-/* mkfs - file system types */
-	list = str_list_create (_(fs_type_msg_start), NULL);
-
-	first = 1;
-	for (fs_type = ped_file_system_type_get_next (NULL);
-	     fs_type; fs_type = ped_file_system_type_get_next (fs_type)) {
-		if (fs_type->ops->create == NULL)
-			continue;
-
-		if (first)
-			first = 0;
-		else
-			str_list_append (list, ", ");
-		str_list_append (list, fs_type->name);
-	}
-	str_list_append (list, "\n");
-
-	mkfs_fs_type_msg = str_list_convert (list);
-	str_list_destroy (list);
-
 /* mkpart - file system types */
 	list = str_list_create (_(fs_type_msg_start), NULL);
 
@@ -2107,26 +1929,6 @@ _init_messages ()
 
 	mkpart_fs_type_msg = str_list_convert (list);
 	str_list_destroy (list);
-
-/* resize - file system types */
-	list = str_list_create (_(resize_msg_start), NULL);
-
-	first = 1;
-	for (fs_type = ped_file_system_type_get_next (NULL);
-	     fs_type; fs_type = ped_file_system_type_get_next (fs_type)) {
-		if (fs_type->ops->resize == NULL)
-			continue;
-
-		if (first)
-			first = 0;
-		else
-			str_list_append (list, ", ");
-		str_list_append (list, fs_type->name);
-	}
-	str_list_append (list, "\n");
-
-	resize_fs_type_msg = str_list_convert (list);
-	str_list_destroy (list);
 }
 
 static void
@@ -2230,56 +2032,34 @@ _init_ex_menu_commands () {
 
 
   if (!compat_mode)
-  {
+    {
+	    fdisk_command_register (fdisk_ex_menu_commands,
+                              fdisk_command_create (str_list_create_unique ("v", _("v"), NULL),
+                                                    do_move,
+                                                    str_list_create (_(" v   move a partition"), NULL),
+                                                    str_list_create (_(number_msg), _(start_end_msg), NULL),
+                                                    1));
 
-	fdisk_command_register (
-		fdisk_ex_menu_commands,
-			fdisk_command_create (
-				str_list_create_unique ("v", _("v"), NULL),
-				do_move,
-				str_list_create (_(" v   move a partition"), NULL),
-				str_list_create (_(number_msg), _(start_end_msg), NULL),
-			1)
-		);
+      fdisk_command_register (fdisk_ex_menu_commands, 
+                              fdisk_command_create (str_list_create_unique ("c", _("c"), NULL),
+                                                    do_rescue,
+                                                    str_list_create (_(" c   rescue a lost partition"), NULL),
+                                                    str_list_create (_(start_end_msg), NULL), 1));
 
-	fdisk_command_register (fdisk_ex_menu_commands, fdisk_command_create (
-		str_list_create_unique ("c", _("c"), NULL),
-		do_rescue,
-		str_list_create (
-_(" c   rescue a lost partition"),
-NULL),
-		str_list_create (_(start_end_msg), NULL), 1));
+      fdisk_command_register (fdisk_ex_menu_commands, 
+                              fdisk_command_create (str_list_create_unique ("z", _("z"), NULL),
+                                                    do_resize,
+                                                    str_list_create (_(" z   resize a partition"),
+                                                                     NULL), NULL, 1));
 
-	fdisk_command_register (fdisk_ex_menu_commands, fdisk_command_create (
-		str_list_create_unique ("z", _("z"), NULL),
-		do_resize,
-		str_list_create (
-_(" z   resize a partition and its file system"),
-NULL), NULL, 1));
+      fdisk_command_register (fdisk_ex_menu_commands, 
+                              fdisk_command_create (str_list_create_unique ("h", _("h"), NULL),
+                                                    do_check,
+                                                    str_list_create (_(" h   check the consistency of a partition"), NULL), 
+                                                    NULL, 
+                                                    1));
+    }
 
-	fdisk_command_register (fdisk_ex_menu_commands, fdisk_command_create (
-		str_list_create_unique ("h", _("h"), NULL),
-		do_check,
-		str_list_create (
-_(" h   check the consistency of a partition"),
-NULL), NULL, 1));
-
-	fdisk_command_register (fdisk_ex_menu_commands, fdisk_command_create (
-		str_list_create_unique ("o", _("o"), NULL),
-		do_copy,
-		str_list_create (
-_(" o   copy the partition over another partition"),
-NULL), NULL, 1));
-
-	fdisk_command_register (fdisk_ex_menu_commands, fdisk_command_create (
-		str_list_create_unique ("k", _("k"), NULL),
-		do_mkfs,
-		str_list_create (
-_(" k   creates a filesystem on a partition"),
-NULL), NULL, 1));
-
-
-  }
   if (compat_mode)
 	fdisk_command_register (fdisk_ex_menu_commands, fdisk_command_create (
 		str_list_create_unique ("b", _("b"), NULL),
