@@ -57,6 +57,7 @@
 #endif /* !ENABLE_NLS */
 
 #include "strlist.h"
+#include "common.h"
 
 #define MIN(a,b)	( (a<b)?  a : b )
 
@@ -472,7 +473,7 @@ str_list_print_wrap (const StrList* list, int line_length, int offset,
 	int		search_result;
 	int		line_break;
 
-	PED_ASSERT (line_length - indent > 10, return);
+	XASSERT (line_length - indent > 10, return);
 
 	spaces = get_spaces (indent);
 	line_left = line_length - offset;
